View source: R/performance_ior.R
| performance_ior | R Documentation |
The Interval Odds Ratio (IOR) evaluates the fixed effect of a cluster-level
(level 2) covariate by explicitly incorporating the residual between-cluster
heterogeneity. interval_odds_ratio() is an alias for performance_ior().
performance_ior(x)
interval_odds_ratio(x)
x |
A (logistic) multilevel model. |
Unlike a standard confidence interval (which reflects sample estimation uncertainty around the coefficients), the IOR reflects the variation in odds ratios across clusters due to residual cluster heterogeneity.
IOR does not contain 1: If the entire interval is above 1 (or below 1), the cluster-level covariate has a strong effect. Even when moving from a "good" unexposed cluster to a "bad" exposed cluster (or vice versa), the directional effect of the covariate remains dominant.
IOR contains 1: When the interval contains 1, the between-cluster heterogeneity is larger than the effect of the covariate itself. This means an individual moving from an unexposed cluster to an exposed cluster could actually experience lower odds of the outcome if the new cluster happens to have a very low unobserved random effect.
A data frame with the parameter names and their interval odds ratios.
Larsen K, Merlo J. Appropriate Assessment of Neighborhood Effects on Individual Health: Integrating Random and Fixed Effects in Multilevel Logistic Regression. American Journal of Epidemiology (2005) 161:81–88. \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1093/aje/kwi017")}
Merlo J, Wagner P, Ghith N, Leckie G. An Original Stepwise Multilevel Logistic Regression Analysis of Discriminatory Accuracy: The Case of Neighbourhoods and Health. PLoS ONE (2016) 11:e0153778. \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1371/journal.pone.0153778")}
performance_poor() and performance_mor() as additional
metrics specifically for logistic multilevel regression models, and icc()
for multilevel models in general.
data(sleepstudy, package = "lme4")
sleepstudy$mygrp <- sample(1:5, size = 180, replace = TRUE)
sleepstudy$high_reaction <- as.factor(datawizard::categorize(sleepstudy$Reaction))
m <- lme4::glmer(
high_reaction ~ Days + (1 | Subject),
data = sleepstudy,
family = "binomial"
)
performance_ior(m)
m <- suppressWarnings(lme4::glmer(
high_reaction ~ Days + (1 | mygrp) + (1 | Subject),
data = sleepstudy,
family = "binomial"
))
performance_ior(m)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.